# PDB-protein-res
-----
## pyresid

python (protein structure) residual ID

You need to install the english models for `spaCy` with:

```
pip install https://github.com/explosion/spacy-models/releases/download/en_core_web_md-1.2.0/en_core_web_md-1.2.0.tar.gz
``` 

-----

## License

Licensed under BSD 3-Clause License

Copyright (c) 2018, Robert Elliot Firth (Science and Techology Faclities Council) 
All rights reserved.

See LICENSE.txt.